==> qtimgren-0.3.2.tar.gz: qtimgren-0.3.2/i18n/qtimgren_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>About</name>
    <message>
        <location filename="../qtimgren/about.ui" line="17"/>
        <source>About</source>
        <translation>A propos</translation>
    </message>
    <message>
        <location filename="../qtimgren/about.ui" line="67"/>
        <source>Version: </source>
        <translation>Version : </translation>
    </message>
    <message>
        <location filename="../qtimgren/about.ui" line="80"/>
        <source>(pyimgren version: 0.0.0)</source>
        <translation>(pyimgren version : 0.0.0)</translation>
    </message>
    <message>
        <location filename="../qtimgren/about.ui" line="35"/>
        <source>Ok</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../qtimgren/about.ui" line="54"/>
        <source>QtImgren</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <location filename="../qtimgren/profile.ui" line="14"/>
        <source>Profile</source>
        <translation>Profil</translation>
    </message>
    <message>
        <location filename="../qtimgren/profile.ui" line="37"/>
        <source>&amp;Name</source>
        <translation>&amp;Nom</translation>
    </message>
    <message>
        <location filename="../qtimgren/profile.ui" line="47"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Name of the profile&lt;/p&gt;&lt;p&gt;Will be used in the &lt;span style=&quot; font-style:italic;&quot;&gt;Profiles&lt;/span&gt; menu&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Nom du profil&lt;/p&gt;&lt;p&gt;Servira d&apos;entrée dans le menu &lt;span style=&quot; font-style:italic;&quot;&gt;Profils&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../qtimgren/profile.ui" line="91"/>
        <source>Path of the image (jpeg) files</source>
        <translation>Répertoire des fichiers image (jpeg)</translation>
    </message>
    <message>
        <location filename="../qtimgren/profile.ui" line="104"/>
        <source>&amp;Select</source>
        <translation>&amp;Choisir</translation>
    </message>
    <message>
        <location filename="../qtimgren/profile.ui" line="112"/>
        <source>Image &amp;mask</source>
        <translation>&amp;Masque des images</translation>
    </message>
    <message>
        <location filename="../qtimgren/profile.ui" line="122"/>
        <source>Pattern of camera images (e.g. IMG*.JPG or DSCF*.JPG)</source>
        <translation>Modèles des noms de fichiers image (par example IMG*.JPG ou DSCF*.JPG)</translation>
    </message>
    <message>
        <location filename="../qtimgren/profile.ui" line="60"/>
        <source>&amp;Directory</source>
        <translation>&amp;Dossier</translation>
    </message>
    <message>
        <location filename="../qtimgren/profile.ui" line="125"/>
        <source>*.JPG</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../qtimgren/profile.ui" line="132"/>
        <source>New name &amp;pattern</source>
        <translation>M&amp;odèle de nouveau nom</translation>
    </message>
    <message>
        <location filename="../qtimgren/profile.ui" line="142"/>
        <source>%Y%m%d_%H%M%S.jpg</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../qtimgren/main_window.ui" line="14"/>
        <source>QtImgren</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../qtimgren/main_window.ui" line="132"/>
        <source>&amp;File</source>
        <translation>&amp;Fichier</translation>
    </message>
    <message>
        <location filename="../qtimgren/main_window.ui" line="140"/>
        <source>&amp;Help</source>
        <translation>&amp;?</translation>
    </message>
    <message>
        <location filename="../qtimgren/main_window.ui" line="147"/>
        <source>&amp;Profiles</source>
        <translation>&amp;Profils</translation>
    </message>
    <message>
        <location filename="../qtimgren/main_window.ui" line="160"/>
        <source>&amp;Quit</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <location filename="../qtimgren/main_window.ui" line="165"/>
        <source>&amp;About</source>
        <translation>&amp;A propos</translation>
    </message>
    <message>
        <location filename="../qtimgren/main_window.ui" line="170"/>
        <source>About &amp;Qt</source>
        <translation>A propos de &amp;Qt</translation>
    </message>
    <message>
        <location filename="../qtimgren/main_window.ui" line="175"/>
        <source>&amp;New profile</source>
        <translation>&amp;Nouveau profil</translation>
    </message>
    <message>
        <location filename="../qtimgren/main_window.ui" line="180"/>
        <source>&amp;Manage profiles</source>
        <translation>&amp;Gestion des profils</translation>
    </message>
    <message>
        <location filename="../qtimgren/main_window.ui" line="185"/>
        <source>Change &amp;Folder</source>
        <translation>Change de &amp;répertoire</translation>
    </message>
    <message>
        <location filename="../qtimgren/main_window.ui" line="193"/>
        <source>&amp;Merge</source>
        <translation>&amp;Combine</translation>
    </message>
    <message>
        <location filename="../qtimgren/main_window.ui" line="29"/>
        <source>Display &amp;images</source>
        <translation>Affiche les &amp;images</translation>
    </message>
    <message>
        <location filename="../qtimgren/main_window.ui" line="52"/>
        <source>Automatic selections</source>
        <translation>Sélections automatiques</translation>
    </message>
    <message>
        <location filename="../qtimgren/main_window.ui" line="60"/>
        <source>Default &amp;selection</source>
        <translation>&amp;Sélection par défaut</translation>
    </message>
    <message>
        <location filename="../qtimgren/main_window.ui" line="67"/>
        <source>Select renamed &amp;images</source>
        <translation>Images re&amp;nommées</translation>
    </message>
    <message>
        <location filename="../qtimgren/main_window.ui" line="81"/>
        <source>&amp;Delta (minutes)</source>
        <translation>Décalage (minutes)</translation>
    </message>
    <message>
        <location filename="../qtimgren/main_window.ui" line="104"/>
        <source>&amp;Rename</source>
        <translation>&amp;Renomme</translation>
    </message>
    <message>
        <location filename="../qtimgren/main_window.ui" line="111"/>
        <source>&amp;Back</source>
        <translation>Noms d&apos;&amp;origine</translation>
    </message>
</context>
<context>
    <name>profile</name>
    <message>
        <location filename="../qtimgren/profile.py" line="73"/>
        <source>&quot;{}&quot; is already used</source>
        <translation>&quot;{}&quot; est déjà utilisé</translation>
    </message>
    <message>
        <location filename="../qtimgren/profile.py" line="77"/>
        <source>Name cannot be empty</source>
        <translation>Le nom ne peut pas être vide</translation>
    </message>
    <message>
        <location filename="../qtimgren/profile.py" line="88"/>
        <source>&quot;{}&quot; is not a valid image pattern</source>
        <translation>&quot;{}&quot; n&apos;est pas un modèle valide</translation>
    </message>
    <message>
        <location filename="../qtimgren/profile.py" line="78"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="../qtimgren/profile.py" line="83"/>
        <source>Path</source>
        <translation>Répertoire</translation>
    </message>
    <message>
        <location filename="../qtimgren/profile.py" line="89"/>
        <source>Mask</source>
        <translation>Modèle</translation>
    </message>
    <message>
        <location filename="../qtimgren/profile.py" line="97"/>
        <source>&quot;{}&quot; is not a valid date pattern</source>
        <translation>&quot;{}&quot; n&apos;est pas un modèle de date valide</translation>
    </message>
    <message>
        <location filename="../qtimgren/profile.py" line="98"/>
        <source>Pattern</source>
        <translation>Modèle de data</translation>
    </message>
</context>
<context>
    <name>profile_manager</name>
    <message>
        <location filename="../qtimgren/profile_manager.py" line="77"/>
        <source>{} already exists</source>
        <translation>{} existe déjà</translation>
    </message>
</context>
<context>
    <name>profiles</name>
    <message>
        <location filename="../qtimgren/profiles.ui" line="14"/>
        <source>Profiles</source>
        <translation>Profils</translation>
    </message>
    <message>
        <location filename="../qtimgren/profiles.ui" line="36"/>
        <source>Edit the (first) selected profile</source>
        <translation>Édite le (premier) profil sélectionné</translation>
    </message>
    <message>
        <location filename="../qtimgren/profiles.ui" line="39"/>
        <source>&amp;Edit</source>
        <translation>&amp;Edite</translation>
    </message>
    <message>
        <location filename="../qtimgren/profiles.ui" line="46"/>
        <source>Remove every selected profile</source>
        <translation>Supprime tous les profils sélectionnés</translation>
    </message>
    <message>
        <location filename="../qtimgren/profiles.ui" line="49"/>
        <source>&amp;Remove</source>
        <translation>&amp;Supprime</translation>
    </message>
    <message>
        <location filename="../qtimgren/profile.py" line="82"/>
        <source>&quot;{}&quot; is not a valid folder</source>
        <translation>&quot;{}&quot; n&apos;est pas un dossier valide</translation>
    </message>
    <message>
        <location filename="../qtimgren/profiles.py" line="42"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="../qtimgren/profiles.py" line="43"/>
        <source>Path</source>
        <translation>Répertoire</translation>
    </message>
    <message>
        <location filename="../qtimgren/profiles.py" line="44"/>
        <source>Mask</source>
        <translation>Modèle</translation>
    </message>
    <message>
        <location filename="../qtimgren/profiles.py" line="46"/>
        <source>Pattern</source>
        <translation>Modèle de date</translation>
    </message>
    <message>
        <location filename="../qtimgren/profiles.py" line="127"/>
        <source>&quot;{1}&quot; is a duplicate&lt;br/&gt;already present at row {0}</source>
        <translation>{1} est déjà présent&lt;br/&gt;ligne {0}</translation>
    </message>
</context>
</TS>

==> qtimgren-0.4.1.tar.gz: qtimgren-0.4.1/i18n/qtimgren_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>About</name>
    <message>
        <location filename="../qtimgren/about.ui" line="17"/>
        <source>About</source>
        <translation>A propos</translation>
    </message>
    <message>
        <location filename="../qtimgren/about.ui" line="67"/>
        <source>Version: </source>
        <translation>Version : </translation>
    </message>
    <message>
        <location filename="../qtimgren/about.ui" line="80"/>
        <source>(pyimgren version: 0.0.0)</source>
        <translation>(pyimgren version : 0.0.0)</translation>
    </message>
    <message>
        <location filename="../qtimgren/about.ui" line="35"/>
        <source>Ok</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../qtimgren/about.ui" line="54"/>
        <source>QtImgren</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <location filename="../qtimgren/profile.ui" line="14"/>
        <source>Profile</source>
        <translation>Profil</translation>
    </message>
    <message>
        <location filename="../qtimgren/profile.ui" line="37"/>
        <source>&amp;Name</source>
        <translation>&amp;Nom</translation>
    </message>
    <message>
        <location filename="../qtimgren/profile.ui" line="47"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Name of the profile&lt;/p&gt;&lt;p&gt;Will be used in the &lt;span style=&quot; font-style:italic;&quot;&gt;Profiles&lt;/span&gt; menu&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Nom du profil&lt;/p&gt;&lt;p&gt;Servira d&apos;entrée dans le menu &lt;span style=&quot; font-style:italic;&quot;&gt;Profils&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../qtimgren/profile.ui" line="91"/>
        <source>Path of the image (jpeg) files</source>
        <translation>Répertoire des fichiers image (jpeg)</translation>
    </message>
    <message>
        <location filename="../qtimgren/profile.ui" line="104"/>
        <source>&amp;Select</source>
        <translation>&amp;Choisir</translation>
    </message>
    <message>
        <location filename="../qtimgren/profile.ui" line="112"/>
        <source>Image &amp;mask</source>
        <translation>&amp;Masque des images</translation>
    </message>
    <message>
        <location filename="../qtimgren/profile.ui" line="122"/>
        <source>Pattern of camera images (e.g. IMG*.JPG or DSCF*.JPG)</source>
        <translation>Modèles des noms de fichiers image (par example IMG*.JPG ou DSCF*.JPG)</translation>
    </message>
    <message>
        <location filename="../qtimgren/profile.ui" line="60"/>
        <source>&amp;Directory</source>
        <translation>&amp;Dossier</translation>
    </message>
    <message>
        <location filename="../qtimgren/profile.ui" line="132"/>
        <source>New name &amp;pattern</source>
        <translation>M&amp;odèle de nouveau nom</translation>
    </message>
    <message>
        <location filename="../qtimgren/profile.ui" line="125"/>
        <source>*.JPG</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../qtimgren/profile.ui" line="142"/>
        <source>%Y%m%d_%H%M%S.jpg</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../qtimgren/merge.ui" line="14"/>
        <source>Folder to merge</source>
        <translation>Dossier à combiner</translation>
    </message>
    <message>
        <location filename="../qtimgren/merge.ui" line="28"/>
        <source>&amp;Folder</source>
        <translation>&amp;Dossier</translation>
    </message>
    <message>
        <location filename="../qtimgren/merge.ui" line="41"/>
        <source>&amp;Change</source>
        <translation>&amp;Changer</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../qtimgren/main_window.ui" line="132"/>
        <source>&amp;File</source>
        <translation>&amp;Fichier</translation>
    </message>
    <message>
        <location filename="../qtimgren/main_window.ui" line="141"/>
        <source>&amp;Help</source>
        <translation>&amp;?</translation>
    </message>
    <message>
        <location filename="../qtimgren/main_window.ui" line="148"/>
        <source>&amp;Profiles</source>
        <translation>&amp;Profils</translation>
    </message>
    <message>
        <location filename="../qtimgren/main_window.ui" line="161"/>
        <source>&amp;Quit</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <location filename="../qtimgren/main_window.ui" line="166"/>
        <source>&amp;About</source>
        <translation>&amp;A propos</translation>
    </message>
    <message>
        <location filename="../qtimgren/main_window.ui" line="171"/>
        <source>About &amp;Qt</source>
        <translation>A propos de &amp;Qt</translation>
    </message>
    <message>
        <location filename="../qtimgren/main_window.ui" line="176"/>
        <source>&amp;New profile</source>
        <translation>&amp;Nouveau profil</translation>
    </message>
    <message>
        <location filename="../qtimgren/main_window.ui" line="181"/>
        <source>&amp;Manage profiles</source>
        <translation>&amp;Gestion des profils</translation>
    </message>
    <message>
        <location filename="../qtimgren/main_window.ui" line="186"/>
        <source>Change &amp;Folder</source>
        <translation>Change de &amp;répertoire</translation>
    </message>
    <message>
        <location filename="../qtimgren/main_window.ui" line="194"/>
        <source>&amp;Merge</source>
        <translation>Com&amp;bine</translation>
    </message>
    <message>
        <location filename="../qtimgren/main_window.ui" line="29"/>
        <source>Display &amp;images</source>
        <translation>Affiche les &amp;images</translation>
    </message>
    <message>
        <location filename="../qtimgren/main_window.ui" line="52"/>
        <source>Automatic selections</source>
        <translation>Sélections automatiques</translation>
    </message>
    <message>
        <location filename="../qtimgren/main_window.ui" line="60"/>
        <source>Default &amp;selection</source>
        <translation>&amp;Sélection par défaut</translation>
    </message>
    <message>
        <location filename="../qtimgren/main_window.ui" line="67"/>
        <source>Select renamed &amp;images</source>
        <translation>Images re&amp;nommées</translation>
    </message>
    <message>
        <location filename="../qtimgren/main_window.ui" line="81"/>
        <source>&amp;Delta (minutes)</source>
        <translation>Décalage (minutes)</translation>
    </message>
    <message>
        <location filename="../qtimgren/main_window.ui" line="104"/>
        <source>&amp;Rename</source>
        <translation>&amp;Renomme</translation>
    </message>
    <message>
        <location filename="../qtimgren/main_window.ui" line="111"/>
        <source>&amp;Back</source>
        <translation>Noms d&apos;&amp;origine</translation>
    </message>
    <message>
        <location filename="../qtimgren/main_window.ui" line="199"/>
        <source>&amp;Settings</source>
        <translation>&amp;Configuration</translation>
    </message>
    <message>
        <location filename="../qtimgren/main_window.ui" line="14"/>
        <source>QtImgren</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>app</name>
    <message>
        <location filename="../qtimgren/app.py" line="57"/>
        <source>English</source>
        <translation>Anglais</translation>
    </message>
    <message>
        <location filename="../qtimgren/app.py" line="19"/>
        <source>French</source>
        <translation>Français</translation>
    </message>
</context>
<context>
    <name>merge</name>
    <message>
        <location filename="../qtimgren/merge_dialog.py" line="34"/>
        <source>New folder</source>
        <translation>Nouveau dossier</translation>
    </message>
</context>
<context>
    <name>profile</name>
    <message>
        <location filename="../qtimgren/profile.py" line="73"/>
        <source>&quot;{}&quot; is already used</source>
        <translation>&quot;{}&quot; est déjà utilisé</translation>
    </message>
    <message>
        <location filename="../qtimgren/profile.py" line="77"/>
        <source>Name cannot be empty</source>
        <translation>Le nom ne peut pas être vide</translation>
    </message>
    <message>
        <location filename="../qtimgren/profile.py" line="88"/>
        <source>&quot;{}&quot; is not a valid image pattern</source>
        <translation>&quot;{}&quot; n&apos;est pas un modèle valide</translation>
    </message>
    <message>
        <location filename="../qtimgren/profile.py" line="78"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="../qtimgren/profile.py" line="83"/>
        <source>Path</source>
        <translation>Répertoire</translation>
    </message>
    <message>
        <location filename="../qtimgren/profile.py" line="89"/>
        <source>Mask</source>
        <translation>Modèle</translation>
    </message>
    <message>
        <location filename="../qtimgren/profile.py" line="97"/>
        <source>&quot;{}&quot; is not a valid date pattern</source>
        <translation>&quot;{}&quot; n&apos;est pas un modèle de date valide</translation>
    </message>
    <message>
        <location filename="../qtimgren/profile.py" line="98"/>
        <source>Pattern</source>
        <translation>Modèle de date</translation>
    </message>
</context>
<context>
    <name>profile_manager</name>
    <message>
        <location filename="../qtimgren/profile_manager.py" line="77"/>
        <source>{} already exists</source>
        <translation>{} existe déjà</translation>
    </message>
</context>
<context>
    <name>profiles</name>
    <message>
        <location filename="../qtimgren/profiles.ui" line="14"/>
        <source>Profiles</source>
        <translation>Profils</translation>
    </message>
    <message>
        <location filename="../qtimgren/profiles.ui" line="36"/>
        <source>Edit the (first) selected profile</source>
        <translation>Édite le (premier) profil sélectionné</translation>
    </message>
    <message>
        <location filename="../qtimgren/profiles.ui" line="39"/>
        <source>&amp;Edit</source>
        <translation>&amp;Edite</translation>
    </message>
    <message>
        <location filename="../qtimgren/profiles.ui" line="46"/>
        <source>Remove every selected profile</source>
        <translation>Supprime tous les profils sélectionnés</translation>
    </message>
    <message>
        <location filename="../qtimgren/profiles.ui" line="49"/>
        <source>&amp;Remove</source>
        <translation>&amp;Supprime</translation>
    </message>
    <message>
        <location filename="../qtimgren/profile.py" line="82"/>
        <source>&quot;{}&quot; is not a valid folder</source>
        <translation>&quot;{}&quot; n&apos;est pas un dossier valide</translation>
    </message>
    <message>
        <location filename="../qtimgren/profiles.py" line="42"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="../qtimgren/profiles.py" line="43"/>
        <source>Path</source>
        <translation>Répertoire</translation>
    </message>
    <message>
        <location filename="../qtimgren/profiles.py" line="44"/>
        <source>Mask</source>
        <translation>Modèle</translation>
    </message>
    <message>
        <location filename="../qtimgren/profiles.py" line="46"/>
        <source>Pattern</source>
        <translation>Modèle de date</translation>
    </message>
    <message>
        <location filename="../qtimgren/profiles.py" line="127"/>
        <source>&quot;{1}&quot; is a duplicate&lt;br/&gt;already present at row {0}</source>
        <translation>{1} est déjà présent&lt;br/&gt;ligne {0}</translation>
    </message>
</context>
<context>
    <name>settings</name>
    <message>
        <location filename="../qtimgren/settings.ui" line="14"/>
        <source>Settings</source>
        <translation>Configuration</translation>
    </message>
    <message>
        <location filename="../qtimgren/settings.ui" line="31"/>
        <source>&amp;Use cache</source>
        <translation>&amp;Utilisation du cache</translation>
    </message>
    <message>
        <location filename="../qtimgren/settings.ui" line="41"/>
        <source>If unchecked no image caching will occur. It will save memory at the price of slow and not smocth scrolling</source>
        <translation>Si non coché, les vignettes ne seront pas mise en cache. Cela économise de la mémoire au prix d&apos;un défilement long et saccadé</translation>
    </message>
    <message>
        <location filename="../qtimgren/settings.ui" line="51"/>
        <source>Cache &amp;size</source>
        <translation>&amp;Taille du cache</translation>
    </message>
    <message>
        <location filename="../qtimgren/settings.ui" line="61"/>
        <source>Maximum number of images that can be cached or &quot;unlimited&apos;. It should be unlimited if you have enough memory, but can allow qtimgren to run on smaller systems.</source>
        <translation>Nombre maximum d&apos;images à mettre en cache ou &quot;illimité&quot;. Utiliser de préférnce illimité si vous avez suffisamment de mémoire, mais des valeurs faibles peuvent permettre à qtimgren de fonctionner sur des systèmes limités.</translation>
    </message>
    <message>
        <location filename="../qtimgren/settings.ui" line="64"/>
        <source>Unlimited</source>
        <translation>Illimité</translation>
    </message>
    <message>
        <location filename="../qtimgren/settings.ui" line="83"/>
        <source>Choose the language for the interface</source>
        <translation>Choix de la langue utilisée dans l&apos;application</translation>
    </message>
    <message>
        <location filename="../qtimgren/settings.ui" line="86"/>
        <source>&amp;Language</source>
        <translation>&amp;Langue</translation>
    </message>
    <message>
        <location filename="../qtimgren/settings.py" line="16"/>
        <source>English</source>
        <translation type="obsolete">Anglais</translation>
    </message>
</context>
<context>
    <name>view</name>
    <message>
        <location filename="../qtimgren/abstract_view.py" line="56"/>
        <source>Image</source>
        <translation>Image</translation>
    </message>
    <message>
        <location filename="../qtimgren/abstract_view.py" line="56"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="../qtimgren/abstract_view.py" line="57"/>
        <source>Original</source>
        <translation>Nom d&apos;origine</translation>
    </message>
    <message>
        <location filename="../qtimgren/abstract_view.py" line="58"/>
        <source>New name</source>
        <translation>Nouveau nom</translation>
    </message>
</context>
</TS>
